Secp256k1

Struct Secp256k1 

pub struct Secp256k1 { /* private fields */ }
Secp256k1 - a short Weierstrass elliptic curve of the form y^2 = x^3 + 7 over the prime field of modulus 2^256 - 2^32 - 977.

Implementations

Source

impl Secp256k1

pub fn new(b: &CircuitBuilder) -> Self

Creates new curve struct with constants related to curve and its coordinate and scalar fields.

pub const fn f_p(&self) -> &PseudoMersennePrimeField

Coordinate field.

pub const fn f_scalar(&self) -> &PseudoMersennePrimeField

Scalar field.

pub fn assert_on_curve(&self, b: &CircuitBuilder, p: &Secp256k1Affine)

Assert that given affine point actually resides on curve.

Considers point-at-infinity not on curve.

pub fn recover( &self, b: &CircuitBuilder, r: &BigUint, recid_odd: Wire, ) -> Secp256k1Affine

Recover the full affine point (r, y) by its x coordinate and y parity. Returns point-at-infinity in case recovery isn’t possible.

Note: we don’t handle the case where r does not fit into the scalar field, thus recid is boolean, and not a 0-3 bitmask signifying both parity and scalar field overflow.

pub fn negate_if( &self, b: &CircuitBuilder, cond: Wire, p: &Secp256k1Affine, ) -> Secp256k1Affine

Negate the curve point p if MSB-bool cond is true.

pub fn endomorphism( &self, b: &CircuitBuilder, p: &Secp256k1Affine, ) -> Secp256k1Affine

Compute the endomorphism λ (x, y) = (βx, y).

pub fn add( &self, b: &CircuitBuilder, p1: &Secp256k1Affine, p2: &Secp256k1Affine, ) -> Secp256k1Affine

Add two curve points.

Requires both p1 and p2 to be either valid curve points or points at infinities.

This implementation is complete - it handles the cases of either p1 or p2 being point-at-infinities, as well as being equal (which falls back to doubling).

pub fn add_incomplete( &self, b: &CircuitBuilder, p1: &Secp256k1Affine, p2: &Secp256k1Affine, ) -> Secp256k1Affine

Add two curve points, incomplete.

Requires both p1 and p2 to be either valid curve points or points at infinities.

Unlike Secp256k1::add this implementation does not handle doubling, asserting false in that case.

pub fn double(&self, b: &CircuitBuilder, p: &Secp256k1Affine) -> Secp256k1Affine

Double a curve point.

Requires both p to be either a valid curve point or point at infinity.